dirlay
======

| *Directory layout object for testing and documentation*

.. toctree::
    :maxdepth: 1
    :caption: Details
    :hidden:

    api
    changelog

.. include:: ../badges.md
    :parser: commonmark

.. include:: ../features.md
    :parser: commonmark


Installation
------------

.. tab-set::

    .. tab-item:: pip

        .. code:: shell

            $ pip install dirlay[rich]

    .. tab-item:: uv

        .. code:: shell

            $ uv add dirlay[rich]


.. _usage:

Use cases
---------

.. include:: ../usage.md
    :parser: commonmark
